@@ -30,10 +30,20 @@ class CommonBrowserView(BrowserView):
         return structure
     
     def getLeadMediaTag(self, item, scale="large"):
-        #TODO: Check if its a brains item, else adapt ICanContainMedia first. see below on containsMedia
-        lead = item.leadMedia
+        if hasattr(item, 'leadMedia'):
+            lead = item.leadMedia
+        else:
+            catalog = getToolByName(self.context, 'portal_catalog')
+            brains = catalog.queryCatalog({"UID": item.UID()})
+            if len(brains) != 0:
+                lead = brains[0].leadMedia
+            else:
+                lead = None
+            
         if lead is not None:
-            return '<img src="%(url)s" alt="%(title)s" title="%(title)s" />'%{'url': "%s/image_%s"%(lead, scale), 'title':item.Title}
+                return '<img src="%(url)s" alt="%(title)s" title="%(title)s" />'%{'url': "%s/image_%s"%(lead, scale), 'title':item.Title}
+        else:
+            return ""
         
     def containsMedia(self, item):
         if hasattr(item, 'hasMedia'):
